@@ -37,6 +37,13 @@ KPluginFactory::Result<KPluginFactory> KPluginFactory::loadFactory(const KPlugin
     if (data.isStaticPlugin()) {
         obj = data.staticPlugin().instance();
     } else {
+        if (data.fileName().isEmpty()) {
+            result.errorString = tr("Could not find plugin %1").arg(data.requestedFileName());
+            result.errorText = QStringLiteral("Could not find plugin %1").arg(data.requestedFileName());
+            result.errorReason = INVALID_PLUGIN;
+            qCWarning(KCOREADDONS_DEBUG) << result.errorText;
+            return result;
+        }
         QPluginLoader loader(data.fileName());
         obj = loader.instance();
         if (!obj) {
@@ -169,6 +176,10 @@ void KPluginFactory::logFailedInstantiationMessage(KPluginMetaData data)
 {
     qCWarning(KCOREADDONS_DEBUG) << "KPluginFactory could not load the plugin" << data.fileName();
 }
+void KPluginFactory::logFailedInstantiationMessage(const char *className, KPluginMetaData data)
+{
+    qCWarning(KCOREADDONS_DEBUG) << "KPluginFactory could not create a" << className << "instance from" << data.fileName();
+}
 
 #if KCOREADDONS_BUILD_DEPRECATED_SINCE(4, 0)
 QObject *KPluginFactory::createObject(QObject *parent, const char *className, const QStringList &args)
